*******************************
The sherpa.utils.testing module
*******************************

.. currentmodule:: sherpa.utils.testing

.. automodule:: sherpa.utils.testing

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      requires_data
      requires_ds9
      requires_fits
      requires_group
      requires_package
      requires_stk
      requires_xspec
